@@ -369,7 +369,6 @@ def build_place_perp_order_instructions(context: Context, wallet: Wallet, group:
     # /// 5. `[writable]` bids_ai - TODO
     # /// 6. `[writable]` asks_ai - TODO
     # /// 7. `[writable]` event_queue_ai - TODO
-
     instructions = [
         TransactionInstruction(
             keys=[
@@ -382,7 +381,7 @@ def build_place_perp_order_instructions(context: Context, wallet: Wallet, group:
                 AccountMeta(is_signer=False, is_writable=True, pubkey=perp_market_details.asks),
                 AccountMeta(is_signer=False, is_writable=True, pubkey=perp_market_details.event_queue),
                 *list([AccountMeta(is_signer=False, is_writable=False,
-                                   pubkey=oo_address or SYSTEM_PROGRAM_ADDRESS) for oo_address in account.spot_open_orders_by_index])
+                                   pubkey=oo_address or SYSTEM_PROGRAM_ADDRESS) for oo_address in account.spot_open_orders_by_index[:-1]])
             ],
             program_id=context.mango_program_address,
             data=layouts.PLACE_PERP_ORDER.build(
@@ -566,7 +565,7 @@ def build_withdraw_instructions(context: Context, wallet: Wallet, group: Group,
             AccountMeta(is_signer=False, is_writable=False, pubkey=group.signer_key),
             AccountMeta(is_signer=False, is_writable=False, pubkey=TOKEN_PROGRAM_ID),
             *list([AccountMeta(is_signer=False, is_writable=False,
-                               pubkey=oo_address or SYSTEM_PROGRAM_ADDRESS) for oo_address in account.spot_open_orders_by_index])
+                               pubkey=oo_address or SYSTEM_PROGRAM_ADDRESS) for oo_address in account.spot_open_orders_by_index[:-1]])
         ],
         program_id=context.mango_program_address,
         data=layouts.WITHDRAW.build({
